from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Array, String, Boolean, File, Int, Directory

Feature_Alignment_Py_V0_1_0 = CommandToolBuilder(tool="feature_alignment.py", base_command=["feature_alignment.py"], inputs=[ToolInput(tag="in_in", input_type=Array(t=String(), optional=True), prefix="--in", doc=InputDocumentation(doc="A list of mProphet output files containing all\npeakgroups (use quotes around the filenames)")), ToolInput(tag="in_file_format", input_type=Boolean(optional=True), prefix="--file_format", doc=InputDocumentation(doc="Input file format (openswath, mprophet or peakview)")), ToolInput(tag="in_out", input_type=File(optional=True), prefix="--out", doc=InputDocumentation(doc="Output file with filtered peakgroups")), ToolInput(tag="in_out_matrix", input_type=Boolean(optional=True), prefix="--out_matrix", doc=InputDocumentation(doc="Matrix containing one peak group per row (supports\n.csv, .tsv or .xlsx)")), ToolInput(tag="in_out_ids", input_type=Boolean(optional=True), prefix="--out_ids", doc=InputDocumentation(doc="Id file only containing the ids")), ToolInput(tag="in_out_meta", input_type=Boolean(optional=True), prefix="--out_meta", doc=InputDocumentation(doc="Outfile containing meta information")), ToolInput(tag="in_fdr_cut_off", input_type=Int(optional=True), prefix="--fdr_cutoff", doc=InputDocumentation(doc="Fixed FDR cutoff used for seeding (only assays where\nat least one peakgroup in one run is below this cutoff\nwill be included in the result), see also target_fdr\nfor a non-fixed cutoff")), ToolInput(tag="in_target_fdr", input_type=Int(optional=True), prefix="--target_fdr", doc=InputDocumentation(doc="If parameter estimation is used, which target FDR\nshould be optimized for. If set to lower than 0,\nparameter estimation is turned off.")), ToolInput(tag="in_max_fdr_quality", input_type=Boolean(optional=True), prefix="--max_fdr_quality", doc=InputDocumentation(doc="Extension m-score score cutoff, peakgroups of this\nquality will still be considered for alignment during\nextension")), ToolInput(tag="in_max_rt_diff", input_type=Int(optional=True), prefix="--max_rt_diff", doc=InputDocumentation(doc="Maximal difference in RT (in seconds) for two aligned")), ToolInput(tag="in_frac_selected", input_type=Int(optional=True), prefix="--frac_selected", doc=InputDocumentation(doc="Do not write peakgroup if selected in less than this\nfraction of runs (range 0 to 1)")), ToolInput(tag="in_method", input_type=String(optional=True), prefix="--method", doc=InputDocumentation(doc="Method to use for the clustering (best_overall,\nbest_cluster_score or global_best_cluster_score,\nglobal_best_overall, LocalMST, LocalMSTAllCluster).")), ToolInput(tag="in_verbosity", input_type=Int(optional=True), prefix="--verbosity", doc=InputDocumentation(doc="Verbosity (0 = little)")), ToolInput(tag="in_matrix_output_method", input_type=Boolean(optional=True), prefix="--matrix_output_method", doc=InputDocumentation(doc="Which columns are written besides Intensity (none, RT,\nscore, source or full)")), ToolInput(tag="in_realign_method", input_type=String(optional=True), prefix="--realign_method", doc=InputDocumentation(doc="RT alignment method (diRT, linear, splineR,\nsplineR_external, splinePy, lowess, lowess_biostats,\nlowess_statsmodels, lowess_cython, nonCVSpline,\nCVSpline, Earth, WeightedNearestNeighbour,\nSmoothLLDMedian, None)")), ToolInput(tag="in_force", input_type=Boolean(optional=True), prefix="--force", doc=InputDocumentation(doc="Force alignment")), ToolInput(tag="in_disable_isotopic_grouping", input_type=Boolean(optional=True), prefix="--disable_isotopic_grouping", doc=InputDocumentation(doc="Disable grouping of isotopic variants by\npeptide_group_label")), ToolInput(tag="in_use_d_score_filter", input_type=Int(optional=True), prefix="--use_dscore_filter", doc=InputDocumentation(doc="Discard all peakgroups below this d-score")), ToolInput(tag="in_nr_high_conf_exp", input_type=Int(optional=True), prefix="--nr_high_conf_exp", doc=InputDocumentation(doc="Number of experiments in which the peptide needs to be\nidentified with confidence above fdr_cutoff")), ToolInput(tag="in_read_method", input_type=String(optional=True), prefix="--readmethod", doc=InputDocumentation(doc="Read full or minimal transition groups\n(cminimal,minimal,full)")), ToolInput(tag="in_tmpdir", input_type=Directory(optional=True), prefix="--tmpdir", doc=InputDocumentation(doc="Temporary directory")), ToolInput(tag="in_alignment_score", input_type=Int(optional=True), prefix="--alignment_score", doc=InputDocumentation(doc="Minimal score needed for a feature to be considered\nfor alignment between runs")), ToolInput(tag="in_realign_runs", input_type=Boolean(optional=True), prefix="--realign_runs", doc=InputDocumentation(doc="Deprecated option (equals '--realign_method\nexternal_r')")), ToolInput(tag="in_use_external_r", input_type=Boolean(optional=True), prefix="--use_external_r", doc=InputDocumentation(doc="Deprecated option (equals '--realign_method\nexternal_r')\n")), ToolInput(tag="in_features", input_type=String(), position=0, doc=InputDocumentation(doc="--iso_max_rt_diff 30  Maximal difference in RT (in seconds) for two isotopic"))], outputs=[ToolOutput(tag="out_out", output_type=File(optional=True), selector=InputSelector(input_to_select="in_out", type_hint=File()), doc=OutputDocumentation(doc="Output file with filtered peakgroups"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Feature_Alignment_Py_V0_1_0().translate("wdl", allow_empty_container=True)

